/* This file has been prepared for Doxygen automatic documentation generation.*/
/*! \file *********************************************************************
 *
 * \brief
 *      Headerfile for chargefunc.c
 *
 *      Contains definitions to decide PWM error handling and of halt flags,
 *      and declarations of parameter structs for charging.
 *
 * \par Application note:
 *      AVR458: Charging Li-Ion Batteries with BC100 \n
 *      AVR463: Charging NiMH Batteries with BC100
 *
 * \par Documentation
 *      For comprehensive code documentation, supported compilers, compiler
 *      settings and supported devices see readme.html
 *
 * \author
 *      Atmel Corporation: http://www.atmel.com \n
 *      Support email: avr@atmel.com
 *
 *
 * $Name$
 * $Revision: 4254 $
 * $RCSfile$
 * $URL: http://revisor.norway.atmel.com/AppsAVR8/avr458_Charging_Li-Ion_Batteries_with_BC100/trunk/code/IAR/chargefunc.h $
 * $Date: 2008-07-25 12:32:45 +0200 (fr, 25 jul 2008) $\n
 ******************************************************************************/

#ifndef CHARGEFUNC_H
#define CHARGEFUNC_H

//******************************************************************************
// Temperature definitions (if JAPANREGS is defined in charge.h)
//******************************************************************************
/*! Temperature hysteresis to stop "borderline" temperatures from causing the
 * charging parameters to change all the time.
 */
#define TEMP_HYST 1

#define T0 10	//!< Maximum temperature for range T0.
#define T1 45	//!< Maximum temperature for range T1.
#define T2 50	//!< Maximum temperature for range T2.
#define T3 60	//!< Maximum temperature for range T3.


//******************************************************************************
// PWM error handling
//******************************************************************************
//! Report error if maximum duty cycle doesn't give a sufficient charge current.
#define ABORT_IF_PWM_MAX

//! Report error if minimum duty cycle gives a too great charge current.
#define ABORT_IF_PWM_MIN


//******************************************************************************
// Definitions for HaltFlags
//******************************************************************************
//! Halt if VBAT drops more than the set limit.
#define HALT_VOLTAGE_DROP		0x01

//! Halt if VBAT reaches the set maximum.
#define HALT_VOLTAGE_MAX		0x02

//! Halt if avgIBAT goes below the set minimum.
#define HALT_CURRENT_MIN		0x04

//! Halt if BattData.Temperature rises quicker than the set maximum.
#define HALT_TEMPERATURE_RISE	0x08

//! Halt if TIMER_CHG runs out.
#define HALT_TIME					0x10

//! Flag battery as exhausted if timeout occurs.
#define HALT_FLAG_EXHAUSTION	0x20


//******************************************************************************
// Global variables
//******************************************************************************
extern ChargeParameters_t ChargeParameters;
extern HaltParameters_t HaltParameters;


//******************************************************************************
// Function prototypes
//******************************************************************************
unsigned char ConstantCurrent(void);
unsigned char ConstantVoltage(void);
unsigned char MaxVoltageAndCurrent(void);
unsigned char HaltNow(void);

#endif // CHARGEFUNC_H
